@@ -1533,56 +1533,56 @@ int valoresCalorGas (const gsl_vector *vars, void *p, gsl_vector *func)
 		  
 		  if ([varTit hasPrefix: @"m"])
 		    {
-		      varFactor = [NSString stringWithString: @"kg"] ;
+		      varFactor = @"kg";
 		    }
 		  else if ([varTit hasPrefix: @"T"])
 		    {
-		      varFactor = [NSString stringWithString: @"K"] ;
+		      varFactor = @"K";
 		    }
 		  else if ([varTit hasPrefix: @"L"])
 		    {
-		      varFactor = [NSString stringWithString: @"m"] ;
+		      varFactor = @"m";
 		    }
 		  else if ([varTit hasPrefix: @"t"])
 		    {
-		      varFactor = [NSString stringWithString: @"s"] ;
+		      varFactor = @"s";
 		    }
 		  else if ([varTit hasPrefix: @"S"])
 		    {
-		      varFactor = [NSString stringWithString: @"m2"] ;
+		      varFactor = @"m2";
 		    }
 		  else if ([varTit hasPrefix: @"V"])
 		    {
-		      varFactor = [NSString stringWithString: @"m3"] ;
+		      varFactor = @"m3";
 		    }
 		  else if ([varTit hasPrefix: @"P"])
 		    {
-		      varFactor = [NSString stringWithString: @"Pa"] ;
+		      varFactor = @"Pa";
 		    }
 		  else if ([varTit hasPrefix: @"c"] || [varTit hasPrefix: @"cR"] || 
 			   [varTit hasPrefix: @"cF"])
 		    {
-		      varFactor = [NSString stringWithString: @"J/kg*K"] ;
+		      varFactor = @"J/kg*K";
 		    }
 		  else if ([varTit hasPrefix: @"cf"] || [varTit hasPrefix: @"cv"])
 		    {
-		      varFactor = [NSString stringWithString: @"J/kg"] ;
+		      varFactor = @"J/kg";
 		    }
 		  else if ([varTit hasPrefix: @"k"])
 		    {
-		      varFactor = [NSString stringWithString: @"1/K"] ;
+		      varFactor = @"1/K";
 		    }
 		  else if ([varTit hasPrefix: @"Q"])
 		    {
-		      varFactor = [NSString stringWithString: @"J"] ;
+		      varFactor = @"J";
 		    }
 		  else if ([varTit hasPrefix: @"dQ"])
 		    {
-		      varFactor = [NSString stringWithString: @"W"] ;
+		      varFactor = @"W";
 		    }
 		  else
 		    {
-		      varFactor = [NSString stringWithString: @"m3/s"] ;
+		      varFactor = @"m3/s";
 		    }
 		  //Termina la busqueda del tipo de variable
 		  
