@@ -2058,20 +2058,20 @@ int valores (const gsl_vector *vars, void *p, gsl_vector *func)
 		      [varTit hasPrefix: @"d"])
 		    {
 		      if (sistema== 0)
-			{ varFactor = [NSString stringWithString: @"m"] ; }
+			{ varFactor = @"m"; }
 		      else
-			{ varFactor = [NSString stringWithString: @"ft"] ; } 
+			{ varFactor = @"ft"; }
 		    }
 		  else if ([varTit hasPrefix: @"t"])
 		    { 
-		      varFactor = [NSString stringWithString: @"s"] ; 
+		      varFactor = @"s";
 		    }
 		  else if ([varTit hasPrefix: @"v"])
 		    {
 		      if (sistema== 0)
-			{ varFactor = [NSString stringWithString: @"m/s"] ; }
+			{ varFactor = @"m/s"; }
 		      else
-			{ varFactor = [NSString stringWithString: @"ft/s"] ; } 
+			{ varFactor = @"ft/s"; }
 		    }
 		  else if ([varTit hasPrefix: @"ang"])
 		    { 
@@ -2080,9 +2080,9 @@ int valores (const gsl_vector *vars, void *p, gsl_vector *func)
 		  else
 		    {
 		      if (sistema== 0)
-			{ varFactor = [NSString stringWithString: @"m/s2"] ; }
+			{ varFactor = @"m/s2"; }
 		      else
-			{ varFactor = [NSString stringWithString: @"ft/s2"] ; }  
+			{ varFactor = @"ft/s2"; }
 		    }
 		  //Termina la busqueda del tipo de variable
 		  
