@@ -2229,17 +2229,17 @@ int valoresCinemaCirc (const gsl_vector *vars, void *p, gsl_vector *func)
 		     [varTit hasPrefix: @"y"])
 		    {
 		      if(sistema== 0)
-			{ varFactor = [NSString stringWithString: @"m"] ; }
+			{ varFactor = @"m"; }
 		      else
-			{ varFactor = [NSString stringWithString: @"ft"] ; } 
+			{ varFactor = @"ft"; }
 		    }
 		  else if([varTit hasPrefix: @"t"])
 		    { 
-		      varFactor = [NSString stringWithString: @"s"] ; 
+		      varFactor = @"s";
 		    }
 		  else if([varTit hasPrefix: @"va"])
 		    {
-		      varFactor = [NSString stringWithString: @"rad/s"] ;
+		      varFactor = @"rad/s";
 		    }
 		  else if([varTit hasPrefix: @"ang"])
 		    { 
@@ -2249,32 +2249,32 @@ int valoresCinemaCirc (const gsl_vector *vars, void *p, gsl_vector *func)
 			  [varTit hasPrefix: @"atot"] || [varTit hasPrefix: @"ac"])
 		    {
 		      if(sistema== 0)
-			{ varFactor = [NSString stringWithString: @"m/s2"] ; }
+			{ varFactor = @"m/s2"; }
 		      else
-			{ varFactor = [NSString stringWithString: @"ft/s2"] ; }  
+			{ varFactor = @"ft/s2"; }
 		    }
 		  else if([varTit hasPrefix: @"aa"])
 		    {
-		      varFactor = [NSString stringWithString: @"rad/s2"] ;
+		      varFactor = @"rad/s2";
 		    }
 		  else if([varTit hasPrefix: @"v"])
 		    {
 		      if(sistema== 0)
-			{ varFactor = [NSString stringWithString: @"m/s"] ; }
+			{ varFactor = @"m/s"; }
 		      else
-			{ varFactor = [NSString stringWithString: @"ft/s"] ; }
+			{ varFactor = @"ft/s"; }
 		    }
 		  else if([varTit hasPrefix: @"f"])
 		    {
-		      varFactor = [NSString stringWithString: @"hz"] ;
+		      varFactor = @"hz";
 		    }
 		  else if([varTit hasPrefix: @"T"])
 		    {
-		      varFactor = [NSString stringWithString: @"1/hz"] ;
+		      varFactor = @"1/hz";
 		    }
 		  else
 		    {
-		      varFactor = [NSString stringWithString: @"rev"] ;
+		      varFactor = @"rev";
 		    }
 		  //Termina la busqueda del tipo de variable
 		  
