@@ -978,7 +978,7 @@ int valoresEstatRig (const gsl_vector *vars, void *p, gsl_vector *func)
   while ((unObj = [varCount nextObject]))
     {
       [resultados addObject: [NSNumber numberWithDouble: gsl_vector_get (s->x, countRes)] ] ;
-      [beamStatus addObject: [NSString stringWithString: @""]];
+      [beamStatus addObject: @""];
       countRes = countRes + 1 ;
     }
   
@@ -1554,17 +1554,17 @@ int valoresEstatRig (const gsl_vector *vars, void *p, gsl_vector *func)
 		  if ([varTit hasPrefix: @"m"])
 		    {
 		      if (sistema== 0)
-			{ varFactor = [NSString stringWithString: @"kg"] ; }
+			{ varFactor = @"kg"; }
 		      else
-			{ varFactor = [NSString stringWithString: @"slug"] ; } 
+			{ varFactor = @"slug"; }
 		    }
 		  else if ([varTit hasPrefix: @"f"] || [varTit hasPrefix: @"N"] || 
 			   [varTit hasPrefix: @"t"])
 		    {
 		      if (sistema== 0)
-			{ varFactor = [NSString stringWithString: @"N"] ; }
+			{ varFactor = @"N"; }
 		      else
-			{ varFactor = [NSString stringWithString: @"lb"] ; }
+			{ varFactor = @"lb"; }
 		    }
 		  else if ([varTit hasPrefix: @"ang"])
 		    {
@@ -1573,28 +1573,28 @@ int valoresEstatRig (const gsl_vector *vars, void *p, gsl_vector *func)
 		  else if ([varTit hasPrefix: @"g"])
 		    {
 		      if (sistema== 0)
-			{ varFactor = [NSString stringWithString: @"m/s2"] ; }
+			{ varFactor = @"m/s2"; }
 		      else
-			{ varFactor = [NSString stringWithString: @"ft/s2"] ; }
+			{ varFactor = @"ft/s2"; }
 		    }
 		  else if ([varTit hasPrefix: @"x"] || [varTit hasPrefix: @"y"] || 
 			   [varTit hasPrefix: @"lc"] || [varTit hasPrefix: @"l"])
 		    {
 		      if (sistema== 0)
-			{ varFactor = [NSString stringWithString: @"m"] ; }
+			{ varFactor = @"m"; }
 		      else
-			{ varFactor = [NSString stringWithString: @"ft"] ; }
+			{ varFactor = @"ft"; }
 		    }
 		  else if ([varTit hasPrefix: @"M"])
 		    {
 		      if (sistema== 0)
-			{ varFactor = [NSString stringWithString: @"N*m"] ; }
+			{ varFactor = @"N*m"; }
 		      else
-			{ varFactor = [NSString stringWithString: @"lb*ft"] ; }
+			{ varFactor = @"lb*ft"; }
 		    }
 		  else
 		    {
-		      varFactor = [NSString stringWithString: @"ad"] ; 
+		      varFactor = @"ad";
 		    }
 		  //Termina la busqueda del tipo de variable
 		  
