@@ -736,11 +736,11 @@
   
   if (sistema == 0)
     {
-      gravedad = [NSString stringWithString: @"9.81"] ;
+      gravedad = @"9.81";
     }
   else
     {
-      gravedad = [NSString stringWithString: @"32.2"] ;
+      gravedad = @"32.2";
     }
   
   switch ([nuevo tag])
@@ -1681,7 +1681,7 @@
 {
   int x;
   NSString *field;
-  NSString *objectData = [NSString stringWithString: @""];
+  NSString *objectData = @"";
   NSMutableArray *keys, *values;
   
   keys = [[listaObjetos objectForKey: aNumber] objectForKey: @"Titulos"];
